#!/bin/sh

function set_gpio_out(){
	dir=`pwd`
	cd /sys/class/gpio
	echo "set gpio $1"
	if [ ! -d gpio$1 ];then
		echo $1 > export
	fi
	cd gpio$1
	echo out > direction
	echo $2 > value
	cd $dir
}

function set_gpio_in(){
	dir=`pwd`
	cd /sys/class/gpio
	echo "set gpio $1"
	if [ ! -d gpio$1 ];then
		echo $1 > export
	fi
	cd gpio$1
	echo in > direction
	echo $2 > value
	cd $dir
}

function set_led_blink() {  # $1=led, $2=delay_on(ms), $3=delay_off(ms)
    dir=`pwd`
    if [ -e /sys/class/leds/led$1 ]; then
        echo "timer" > /sys/class/leds/led$1/trigger
        echo $2 > /sys/class/leds/led$1/delay_on
        echo $3 > /sys/class/leds/led$1/delay_off
    fi
    cd $dir
}

function oled_show_reboot() {
    echo 0xae > /sys/class/graphics/fb1/on_spi
    lang=$(grep LANG_SET /opt/tersus/rtk.conf | sed 's/#.*//g' | sed 's/ //g' | awk '{split($0,array,"=")}END{print array[2]}')
    if [ "x$lang" = "x1" ]; then
        cat /opt/tersus/fb/rbt_cn.fb > /dev/fb1
    else
        cat /opt/tersus/fb/rbt_en.fb > /dev/fb1
    fi
    echo 0xaf > /sys/class/graphics/fb1/on_spi
}

function oled_show_upgrade() {
    echo 0xae > /sys/class/graphics/fb1/on_spi
    lang=$(grep LANG_SET /opt/tersus/rtk.conf | sed 's/#.*//g' | sed 's/ //g' | awk '{split($0,array,"=")}END{print array[2]}')
    if [ "x$lang" = "x1" ]; then
        cat /opt/tersus/fb/upd_cn.fb > /dev/fb1
    else
        cat /opt/tersus/fb/upd_en.fb > /dev/fb1
    fi
    echo 0xaf > /sys/class/graphics/fb1/on_spi
}

function oled_clear_screen() {
    dd if=/dev/zero of=/dev/fb1 bs=1k count=1
}

function begin_update() {
    #set led stat, display updating info on oled
    echo "Begin Updating..."
    oled_show_upgrade
    set_led_blink 0 500  0
    set_led_blink 1 500  0
    set_led_blink 2 500  0
    set_led_blink 3 500  0
    set_led_blink 4 500  0
    set_led_blink 5 500  0
}

function end_update() {
    #clear led stat, clear updating info on	 oled
    echo "End Updating..."
    oled_show_reboot
    set_led_blink 0 0  500
    set_led_blink 1 0  500
    set_led_blink 2 0  500
    set_led_blink 3 0  500
    set_led_blink 4 0  500
    set_led_blink 5 0  500
    sleep 1
    #oled_clear_screen
}
function udisk_check() {
	model=$(grep DEV_MODEL /opt/tersus/rtk.conf | sed 's/#.*//g' |  sed 's/ //g' | awk '{split($0,array,"=")}END{print array[2]}')
    if [ -f /update/update.log ]; then
        lastupd=$( tail -n 1 /update/update.log )
    fi
    if [ -d /run/media/sda1/OscarUpdate ]; then
		if [ "x$model" = "x0" ]; then     #Basic Model
			usbupd=$( ls -t /run/media/sda1/OscarUpdate  | grep '^TersusOscar_Release_Basic.*\.tar\.gz$' | head -n 1)
		elif [ "x$model" = "x2" ]; then   #Ultimate Model
			usbupd=$( ls -t /run/media/sda1/OscarUpdate  | grep '^TersusOscar_Release_Ultimate.*\.tar\.gz$' | head -n 1)
		else
			usbupd=$( ls -t /run/media/sda1/OscarUpdate  | grep '^TersusOscar_Release_Advanced.*\.tar\.gz$' | head -n 1)
		fi
    fi
    if [ "x$usbupd" = "x" ]; then
            echo "No udisk update file."
            return -1
    fi
    if [ "x$lastupd" \< "x$usbupd" ]; then
		echo "Update from usb disk."
		cp  /run/media/sda1/OscarUpdate/$usbupd /update/
		sync; sync; sync; sync; sync
		echo 3 > /proc/sys/vm/drop_caches
		blockdev --flushbufs /dev/mmcblk1p1
    else
		echo "Alread updated.."
        return -1
	fi
    
}

function check_update() {
        exedir=$(pwd)
        if [ ! -d /update ]; then 
            mkdir /update
        fi
        udisk_check
        upd=$( ls -t /update  | grep '^TersusOscar_Release.*\.tar\.gz$' | head -n 1)
        if [ "x$upd" = "x" ]; then
                echo "No update task."
                return -1
        fi
        if [ -f /update/update.log ]; then
            lastupd=$( tail -n 1 /update/update.log )
        fi
        if [ "x$upd" \> "x$lastupd" ]; then
            echo "update system with $upd"
			cd /update
			if [ -s $upd  ]; then
                begin_update
                tempdir=$(basename $upd .tar.gz)
                tar -zxf $upd
				if [ $?  -eq 0 ]; then
					sync; sync; sync
					cd  $tempdir
					chmod +x update.sh
					./update.sh
					echo "$upd" >> /update/update.log
					cd ..
				fi
				rm -rf /update/TersusOscar*
				sync; sync
                end_update
                reboot
			fi
        else
			return -1
		fi
        
        cd $exedir
}

check_update


